@@ -137,6 +137,16 @@ public final class UnifiedInboxProperties extends AbstractProtocolProperties imp
         return mailProperties.isAllowNestedDefaultFolderOnAltNamespace();
     }
 
+    @Override
+    public boolean isEnforceSecureConnection() {
+        return mailProperties.isEnforceSecureConnection();
+    }
+
+    @Override
+    public void setEnforceSecureConnection(boolean enforceSecureConnection) {
+        mailProperties.setEnforceSecureConnection(enforceSecureConnection);
+    }
+
     @Override
     public boolean isIgnoreSubscription() {
         return mailProperties.isIgnoreSubscription();
