@@ -749,6 +749,11 @@ public final class UnifiedMailMessage extends MailMessage implements Delegatized
         delegatee.setSubject(subject);
     }
 
+    @Override
+    public void setSubject(String subject, boolean decoded) {
+        delegatee.setSubject(subject, decoded);
+    }
+
     @Override
     public void prepareForCaching() {
         delegatee.prepareForCaching();
